require(['config'], function() {
	require([
		'kakao.map.util'
	], function($) {
		pageObj.init();
	});
});

/********************************************************
 --------------------------------------------------------
 - Object 목록								            -
 --------------------------------------------------------
 * const gridColModel = {}	: 화면 Grid Object			*
 * let pageObj = {}			: 화면공통 Object			*
 * let listObj = {}			: 목록화면 Object			*
 * let viewObj = {}			: 상세화면 Object			*
 * let modifyObj = {}		: 수정화면 Object			*
 * let createObj = {}		: 신규화면 Object			*
 *******************************************************/

/*화면 변수*/
const POMNG03011_GRID_ID = '#ITP_POMNG03011_jqGrid';
const POMNG03011_GRID_LIST = '#ITP_POMNG03011_jqGrid_list';
const POMNG03011_GRID_PAGER = '#ITP_POMNG03011_jqGridPager';
const POMNG03011_GRID_EMPTY = '#ITP_POMNG03011_jqGridEmpty';

const POMNG03011_DETAIL_GRID_ID = '#ITP_POMNG03011_DETAIL_jqGrid';
const POMNG03011_DETAIL_GRID_LIST = '#ITP_POMNG03011_DETAIL_jqGrid_list';
const POMNG03011_DETAIL_GRID_PAGER = '#ITP_POMNG03011_DETAIL_jqGridPager';
const POMNG03011_DETAIL_GRID_EMPTY = '#ITP_POMNG03011_DETAIL_jqGridEmpty';

const POMNG03011_NDETAIL_GRID_ID = '#ITP_POMNG03011_NDETAIL_jqGrid';
const POMNG03011_NDETAIL_GRID_LIST = '#ITP_POMNG03011_NDETAIL_jqGrid_list';
const POMNG03011_NDETAIL_GRID_PAGER = '#ITP_POMNG03011_NDETAIL_jqGridPager';
const POMNG03011_NDETAIL_GRID_EMPTY = '#ITP_POMNG03011_NDETAIL_jqGridEmpty';

let ITP_FORM_POMNG03011_DETAIL_IS_WRITING = false;
let POMNG03011_GRID_LAST_ROW_ID;
let SCREEN_MODE ;

/*API URL*/
let API_DETAIL_GRID_LIST 		= '/api/pomng/po-streamline-grid-list';	// 목록
let API_DETAIL_REJECT 		 	= '/api/pomng/reject-pchReq'; // 구매요청 선택한건 반려 처리 
let API_DETAIL_POPASS_CHK   	= '/api/pomng/po/chk-pchOrd'; // 목록에서 선택한 구매요청건에 대해 발주가능여부 체크 함
let API_DETAIL_PO_INIT_INFO    	= '/api/pomng/po/init-pchOrd'; // 구매요청발주생성 오픈시 호출하여 데이타 세팅함
let API_DETAIL_NEW_INIT_INFO    = '/api/pomng/po/init-poOrd'; // 신규발주생성 오픈시 호출하여 데이타 세팅함
let API_DETAIL_SAVE 		    = '/api/pomng/po/save-pchPo';			// 저장
let API_DETAIL_PASSQTY 		    = '/api/stock/mng/whs-passqty-list';			// 창고선택후 해당 창고의 출고가능수량을 가져옴


/*화면 Grid ColModel*/
function poRowspanSetting(rowId, val, rawObject, cm) {
	if(typeof rawObject.attr=='object' ) {
		var attr = rawObject.attr[cm.name], result=null;

		if(attr ) {
			if (attr.rowspan) {
				result = ' rowspan=' + '"' + attr.rowspan + '"';
			} else if (attr.display) {
				result = ' style="display:' + attr.display + '"';
			}
		}
		return result;
	}
}

const gridColModel = {
	list: [
		{
			index: 'BRAND_NM', name: 'brandNm',
			label: '브랜드',
			width: '10', fixed: false, align: 'center',
			minwidth: 120,
			sortable: false, hidden: true, classes: 'ui-ellipsis' 
		},
		{
			index: 'PCH_REQ_UNQ_NO', name: 'pchReqUnqNo',
			label: '구매요청번호', 
			width: '11', fixed: false, align: 'center',
			minwidth: 180,
			sortable: false, hidden: false, cellattr: poRowspanSetting
		},
		{
			index: 'WHS_NM', name: 'whsNm',
			label: '납품장소',
			width: '10', fixed: false, align: 'left',
			minwidth: 120,
			sortable: false, hidden: false, classes: 'ui-ellipsis', cellattr: poRowspanSetting
		},
		{
			index: 'ITEM_ID', name: 'itemId',
			label: '품목번호', 
			width: '11', fixed: false, align: 'center',
			minwidth: 180,
			sortable: false, hidden: false
		},
		{
			index: 'ITEM_NM', name: 'itemNm',
			label: '품목명', 
			width: '10', fixed: false, align: 'left',
			minwidth: 180,
			sortable: false, hidden: false, classes: 'ui-ellipsis'
		},
		{
			index: 'PCH_REQ_QTY', name: 'pchReqQty',
			label: '구매요청수량',
			width: '12', fixed: false, align: 'right',
			sortable: false, hidden: false,
			formatter:'integer',formatoptions: { defaultValue: '', thousandsSeparator: ',' }
		},
		{
			index: 'DLV_REQ_DT', name: 'dlvReqDt',
			label: '납품요청일', 
			width: '10', fixed: false, align: 'center',
			sortable: false, hidden: false
		},
		{
			index: 'PCH_REQ_AMT', name: 'pchReqAmt',
			label: '구매요청금액',
			width: '12', fixed: false, align: 'right',
			sortable: false, hidden: false,
			formatter:'integer',formatoptions: { defaultValue: '', thousandsSeparator: ',' }
		},
		{
			index: 'DLV_DVSN_NM', name: 'dlvDvsnNm',
			label: '배송구분', 
			width: '9', fixed: false, align: 'center',
			sortable: false, hidden: false
		}
	]
};

/*화면공통 Object*/
let pageObj = {
	init: function () {
		$('#ITP_FORM_POMNG03011_DETAIL_SBRAND_ID').val(fn_make_user_info.get('brandId'));
		$('#ITP_FORM_POMNG03011_DETAIL_SSTORE_ID').val(fn_make_user_info.get('storeId'));
		this.ui.init();
		this.event.init();
		this.action();
	},
	ui: {
		init: function () {
			this.view();
			this.grid();
			this.ready();
		},
		view: function() {
			// 버튼 권한설정
			fn_proc_btn_auth('POMNG03011');

			// 공통코드 표시
			$('select').each(function() {
				if($(this).data('select-code')) {
					fn_make_select(CODE_LIST, $(this).data('select-code'), $(this).attr('id'));
				}
			});

			// 조회일자 지정
			var now = new Date();
			var fromDate = new Date(now);
			fromDate.setDate(now.getDate() - 7);
			var toDate = new Date(now);
			toDate.setDate(now.getDate() + 5);
			$('#ITP_FORM_POMNG03011_SEARCH_FROM_DT').val(itp_fn_get_before_month() );
			$('#ITP_FORM_POMNG03011_SEARCH_TO_DT').val(itp_fn_get_today_ko() );
			$('#ITP_TAB_POMNG03011 .input-group.date').datepicker(ITP_DATE_LANGUAGE);
			$('#ITP_FORM_POMNG03011_SEARCH_FROM_DT').datepicker();
			$('#ITP_FORM_POMNG03011_SEARCH_TO_DT').datepicker();
		},
		grid: function() {
			//listObj.empty.init();
			itp_fn_jqgrid_resize(POMNG03011_GRID_ID, POMNG03011_GRID_LIST, 'lg');
		},
		ready: function() {
			listObj.init();
		}
	},
	action: function () {
		var _this = this;
	},
	popup: function (arg) { 
		
	},
	callback: { 
	},
	event: {
		init: function () {
			this.button();
		},
		button: function () {
			// 버튼 클릭 이벤트
			$('button').each(function() {
				var id = $(this).attr('id');
				$(this).on('click', function() {
					switch (id) {
						case 'ITP_BTN_POMNG03011_SEB': 		listObj.search();	break;	// 조회버튼
						case 'ITP_BTN_POMNG03011_PO': 		listObj.sendPo(); 	break;	// 발주전송
					}
				});
			}); 
		}
		// /api/pomng/po/save-pchSteamlinePo
	},
	switchScreen: function(mode) {
		$('.itp_det_head').find('button[id^="ITP_BTN_POMNG03011_"]').each(function(i) {
			$(this).hide();
		});
		$('#ITP_TAB_POMNG03011').find('div[id$="_CONTAINER"]').each(function(i) {
			$(this).hide();
		});
		if(mode == 'LIST') { // 목록
			itp_fn_fire_window_resize();
			$('#ITP_AJAX_POMNG03011_LIST_CONTAINER').show();
			fn_show_btn_auth_array(['#ITP_BTN_POMNG03011_PO', '#ITP_BTN_POMNG03011_SEB']);
			$('#ITP_FORM_POMNG03011_DETAIL_SBRAND_ID').val(fn_make_user_info.get('brandId'));
			$('#ITP_FORM_POMNG03011_DETAIL_SSTORE_ID').val(fn_make_user_info.get('storeId'));
			
			$('#ITP_FORM_POMNG03011_SDELETE_SSPPLY_NM').show();
			$('#ITP_FORM_POMNG03011_SDELETE_SWHS_NM').show();
			$('#ITP_BTN_POMNG03011_PO').show();
			SCREEN_MODE = 'LIST' ;
		} 
	},
};

/*목록화면 Object*/

let listObj = {
	init: function () {
		this.grid.init();
	},
	itp_POMNG03011_search: false,
	search: function() {
		this.itp_POMNG03011_search = true;
		let param = $('#ITP_FORM_POMNG03011_SEARCH').serializeObject();
		param.gridSize = $.jgrid.defaults.rowNum;
		param.gridPage = $.jgrid.defaults.page; 
		$(POMNG03011_GRID_ID).data('grid-param',param);
		$(POMNG03011_GRID_ID).setGridParam({'postData': JSON.stringify(param)}).trigger('reloadGrid');
	},
	sendPo: function() {
		// 발주전송
		
		const grid=$(POMNG03011_GRID_ID);
		const viewCd='C';
		const gridInsertData = [];
		const brandId=fn_make_user_info.get('brandId');
		const rowKey = grid.getGridParam('selrow');
		if (!rowKey) {
			return itp_fn_modal_alert('선택된 구매발주 요청 내역이 없습니다');
		}
		itp_fn_confirm( '구매발주 요청을 전송 하시겠습니까?', function() {
			var selectedIds = grid.getGridParam('selarrrow');
			for (var i=selectedIds.length-1; i>=0; i--) {
				const cur=grid.jqGrid('getRowData', selectedIds[i]);
				gridInsertData.push({pchReqUnqNo: cur.pchReqUnqNo} );	
			}
			ajaxCall('/api/pomng/po/save-pchSteamlinePo', {viewCd, brandId, gridInsertData }, function(result) {
				if(result.message) itp_fn_modal_alert_ajax(result.message);
				listObj.search();
			}, 'POST');
			$('#ITP_MODAL_ALERT').modal('hide');
		}); 
	}, 
	empty: {
		init: function() {},
		itp_POMNG03011_param: {},
		push: function() {},
		back: function() {}
	},
	grid: {
		init: function () {
			// 데이터 없을때 
			//itp_fn_jqgrid_resize(POMNG03011_GRID_ID, POMNG03011_GRID_LIST, 'lg');
			itp_fn_fire_window_resize();
			this.search();
			
		},
		colModel: gridColModel.list,
		search: function() {
			pageObj.switchScreen('LIST');
			this.unload();
			this.load();
		},
		load: function() {

			let param = $('#ITP_FORM_POMNG03011_SEARCH').serializeObject();
			// param.gridSize = $.jgrid.defaults.rowNum;
			var option = {
				multiselect: true,
				autowidth: true,
				gridId: POMNG03011_GRID_ID,
				colModel: gridColModel.list,
				param: param,
				url: DOMAIN + API_DETAIL_GRID_LIST,
				// pager: POMNG03011_GRID_PAGER,
				rownumbers: false, 
				
				beforeProcessing: function(data) { 
					var rows=data.gridRows;
					var cnt=rows.length, prev1='', prev2='', sp1=0, sp2=0;
					var displayAttr=function(sp, ep, field) {
						var rs=ep-sp;
						if( rs>1 ) {
							for(var n=sp; n<ep; n++) {
								var cur=rows[n], attr=cur.attr;
								if(!attr.hasOwnProperty(field) ) {
									attr[field]={};
								}
								if(n==sp) {
									attr[field].rowspan=rs;
								} else {
									attr[field].display='none';
								}
							}
						}
						
					};
					for(var n=0;n<=cnt; n++) {
						if(n==cnt) {
							displayAttr(sp1, n, 'pchReqUnqNo');
							displayAttr(sp2, n, 'whsNm');
							break;
						} 
						var cur=rows[n];
						cur.attr={ };
						if(prev2!=cur.whsNm) {							
							displayAttr(sp2, n, 'whsNm');
							sp2=n;
							prev2=cur.whsNm;
						}
						if(prev1!=cur.pchReqUnqNo) {
							displayAttr(sp1, n, 'pchReqUnqNo');
							displayAttr(sp2, n, 'whsNm');
							sp1=sp2=n;
							prev2=cur.whsNm;
							prev1=cur.pchReqUnqNo;
						}
						
					}
				}, 
				loadComplete: function(data) {  
					itp_fn_grid_load_complete(data, POMNG03011_GRID_ID, true, 'number', 'POMNG03011', listObj.itp_POMNG03011_search, listObj.empty, true, data.gridRecords, true);
					 
					var ids = $(POMNG03011_GRID_ID).getDataIDs();
					var css = {'background-color':'#FFCCCC'};
					$.each(ids, function(idx, rowId) {
						$(POMNG03011_GRID_ID).jqGrid('setCell', rowId, 'storeId', '', ITP_GRID_COL_STYLE.link);
						$(POMNG03011_GRID_ID).jqGrid('setCell', rowId, 'dlvReqDt', '', css);
						$(POMNG03011_GRID_ID).jqGrid('setCell', rowId, 'whsNm', '', css);
					});
					$('#ITP_POMNG03011_jqGrid_list .cbox.checkbox').each(function(idx) {
						var tds=$(this).closest('tr').children('td'), td=tds.eq(2);
						var rs=td.attr('rowspan'), ds=td.css('display'); 
						if(rs) $(this).closest('td').attr('rowspan', rs);
						else if(ds=='none') $(this).closest('td').hide();
					})
					const self=this;
					if(self.sortUse) return;
					self.sortUse=true;
					self['sort2']='desc'; 
					const th=$(POMNG03011_GRID_LIST).find('.ui-jqgrid-labels .ui-th-div').eq(2);
					th.find('.s-ico').show();
					th.find('.ui-grid-ico-sort').hide();
					th.find('.glyphicon-triangle-top').show();//asc 는 bottom 으로 desc 는 top
					//$(POMNG03011_GRID_LIST).find('.ui-jqgrid-labels .ui-th-div').css('cursor','default');
					$(POMNG03011_GRID_LIST).find('th').eq(2).css({cursor:'pointer',background:'#FFEBCD'});
					$(POMNG03011_GRID_LIST).find('th').eq(3).css({cursor:'pointer',background:'#FFEBCD'});
					$(POMNG03011_GRID_LIST).find('th').eq(5).css({cursor:'pointer',background:'#FFEBCD'});
					$(POMNG03011_GRID_LIST).find('.ui-jqgrid-labels>th').on('click', function() {
						const idx=$(this).index();
						console.log("xxxx grid header click xxxxxxx index=="+idx, param );
						if(idx==2 || idx==3 || idx==5) {
							var field='',sort=self['sort'+idx];
							if(sort ) {
								sort=sort=='asc'?'desc':'asc';
							} else {
								// 등록일 내림차순, 제목 오름차순
								sort=idx==2? 'asc':idx==3? 'desc': 'asc';
							}
							const icon=sort=='asc'? '.glyphicon-triangle-bottom': '.glyphicon-triangle-top'; 
							self['sort'+idx]=sort;
							if(idx==2) {
								field='pchReqUnqNo';
							} else if(idx==3) {
								field='whsNm';
							} else if(idx==5) {
								field='itemNm';
							} 
							param.page=1;
							param.sidx=field;
							param.sord=sort;
							
							$(POMNG03011_GRID_ID).jqGrid('setGridParam',{
								postData:JSON.stringify(param)
							}).trigger('reloadGrid');
							$(this).find('.s-ico').show();
							$(this).find('.ui-grid-ico-sort').hide();
							$(this).find(icon).show();

						}
					});
					// $(POMNG03011_GRID_ID).setSelection(1, true);
				},
				onCellSelect: function(row, col, html, evt) {
					
				},
				onPaging: function(action) {
					itp_fn_grid_paging(POMNG03011_GRID_ID, action, param);
				}
			};
			itp_fn_grid_make_remote(option);
			
		}, 
		unload : function() {
			$.jgrid.gridUnload(POMNG03011_GRID_ID);
		},
		clearData : function() {
			$(POMNG03011_GRID_ID).jqGrid('clearGridData', true);
			$(POMNG03011_GRID_LIST).find('.ui-jqgrid-bdiv').css('min-height', '100px');
			$(POMNG03011_GRID_EMPTY).html(ITP_MSG_LOCALE.message.grid.noData);
			$(POMNG03011_GRID_EMPTY).show();
		}
	}, 
};



