require(['config'], function() {
	require([
		'kakao.map.util'
	], function($) {
		pageObj.init();
	});
});

/********************************************************
 --------------------------------------------------------
 - Object 목록								            -
 --------------------------------------------------------
 * const gridColModel = {}	: 화면 Grid Object			*
 * let pageObj = {}			: 화면공통 Object			*
 * let listObj = {}			: 목록화면 Object			*
 * let viewObj = {}			: 상세화면 Object			*
 * let modifyObj = {}		: 수정화면 Object			*
 * let createObj = {}		: 신규화면 Object			*
 *******************************************************/

/*화면 변수*/
const RTNMNG03011_GRID_ID = '#ITP_RTNMNG03011_jqGrid';
const RTNMNG03011_GRID_LIST = '#ITP_RTNMNG03011_jqGrid_list';
const RTNMNG03011_GRID_PAGER = '#ITP_RTNMNG03011_jqGridPager';
const RTNMNG03011_GRID_EMPTY = '#ITP_RTNMNG03011_jqGridEmpty';

const RTNMNG03011_DETAIL_GRID_ID = '#ITP_RTNMNG03011_DETAIL_jqGrid';
const RTNMNG03011_DETAIL_GRID_LIST = '#ITP_RTNMNG03011_DETAIL_jqGrid_list';
const RTNMNG03011_DETAIL_GRID_PAGER = '#ITP_RTNMNG03011_DETAIL_jqGridPager';
const RTNMNG03011_DETAIL_GRID_EMPTY = '#ITP_RTNMNG03011_DETAIL_jqGridEmpty';

const RTNMNG03011_NDETAIL_GRID_ID = '#ITP_RTNMNG03011_NDETAIL_jqGrid';
const RTNMNG03011_NDETAIL_GRID_LIST = '#ITP_RTNMNG03011_NDETAIL_jqGrid_list';
const RTNMNG03011_NDETAIL_GRID_PAGER = '#ITP_RTNMNG03011_NDETAIL_jqGridPager';
const RTNMNG03011_NDETAIL_GRID_EMPTY = '#ITP_RTNMNG03011_NDETAIL_jqGridEmpty';

let ITP_FORM_RTNMNG03011_DETAIL_IS_WRITING = false;
let RTNMNG03011_GRID_LAST_ROW_ID;
let SCREEN_MODE ;

/*API URL*/
let API_DETAIL_GRID_LIST 		= '/api/rtnmng/rtn-streamline-grid-list';	// 목록
let API_DETAIL_REJECT 		 	= '/api/pomng/reject-pchReq'; // 구매요청 선택한건 반려 처리 
let API_DETAIL_POPASS_CHK   	= '/api/pomng/po/chk-pchOrd'; // 목록에서 선택한 구매요청건에 대해 발주가능여부 체크 함
let API_DETAIL_PO_INIT_INFO    	= '/api/pomng/po/init-pchOrd'; // 구매요청발주생성 오픈시 호출하여 데이타 세팅함
let API_DETAIL_NEW_INIT_INFO    = '/api/pomng/po/init-poOrd'; // 신규발주생성 오픈시 호출하여 데이타 세팅함
let API_DETAIL_SAVE 		    = '/api/pomng/po/save-pchPo';			// 저장
let API_DETAIL_PASSQTY 		    = '/api/stock/mng/whs-passqty-list';			// 창고선택후 해당 창고의 출고가능수량을 가져옴


/*화면 Grid ColModel*/
function retRowspanSetting(rowId, val, rawObject, cm) {
	if(typeof rawObject.attr=='object' ) {
		var attr = rawObject.attr[cm.name], result=null;
		if(attr ) {
			if (attr.rowspan) {
				result = ' rowspan=' + '"' + attr.rowspan + '"';
			} else if (attr.display) {
				result = ' style="display:' + attr.display + '"';
			}
		}
		return result;
	}
} 
const gridColModel = {
	list: [
		{
			index: 'RTN_REQ_UNQ_NO', name: 'rtnReqUnqNo',
			label: '반품요청번호', 
			width: 180, fixed: false, align: 'center',
			minwidth: 180,
			sortable: false, hidden: false, cellattr: retRowspanSetting
		},
		{
			index: 'BRAND_NM', name: 'rtnWhsNm',
			label: '수거장소',
			width: 150, fixed: false, align: 'left',
			minwidth: 120,
			sortable: false, hidden: false, classes: 'ui-ellipsis', cellattr: retRowspanSetting
		},
		{
			index: 'ITEM_ID', name: 'itemId',
			label: '품목번호', 
			width: 180, fixed: false, align: 'center',
			minwidth: 150,
			sortable: false, hidden: false
		},
		{
			index: 'ITEM_NM', name: 'itemNm',
			label: '품목명', 
			width: 250, fixed: false, align: 'left',
			minwidth: 200,
			sortable: false, hidden: false, classes: 'ui-ellipsis'
		},
		{
			index: 'COL_REQ_QTY', name: 'rtnQty',
			label: '수거요청수량',
			width: 100, minwidth:80, fixed: false, align: 'right',
			sortable: false, hidden: false,
			formatter:'integer',formatoptions: { defaultValue: '', thousandsSeparator: ',' }
		},
		{
			index: 'COL_REQ_DT', name: 'rtnReqDt',
			label: '수거요청일', 
			width: 120, minwidth:100, fixed: false, align: 'center',
			sortable: false, hidden: false
		},
		{
			index: 'COL_REQ_AMT', name: 'rtnAmt',
			label: '수거요청금액',
			width: 120, minwidth:100, fixed: false, align: 'right',
			sortable: false, hidden: false,
			formatter:'integer',formatoptions: { defaultValue: '', thousandsSeparator: ',' }
		},
		{
			index: 'RTN_DVSN_NM', name: 'rtnDvsnNm',
			label: '반품구분', 
			width: 100, minwidth:80, fixed: false, align: 'center',
			sortable: false, hidden: false
		},
		{
			index: 'COL_DVSN_NM', name: 'colDvsnNm',
			label: '수거구분', 
			width: 100, minwidth:80, fixed: false, align: 'center',
			sortable: false, hidden: false
		},
		{
			index: 'BRAND_NM', name: 'brandNm',
			label: '브랜드',
			width: 120, minwidth:100, fixed: false, align: 'left', 
			sortable: false, hidden: false, classes: 'ui-ellipsis'
		}
	]
};

/*화면공통 Object*/
let pageObj = {
	init: function () {
		this.ui.init();
		this.event.init();
		this.action();
	},
	ui: {
		init: function () {
			this.view();
			this.grid();
			this.ready();
		},
		view: function() {
			// 버튼 권한설정
			fn_proc_btn_auth('RTNMNG03011');

			// 공통코드 표시
			$('select').each(function() {
				if($(this).data('select-code')) {
					fn_make_select(CODE_LIST, $(this).data('select-code'), $(this).attr('id'));
				}
			});

			// 조회일자 지정
			var now = new Date();
			var fromDate = new Date(now);
			fromDate.setDate(now.getDate() - 7);
			var toDate = new Date(now);
			toDate.setDate(now.getDate() + 5);
			$('#ITP_FORM_RTNMNG03011_SEARCH_FROM_DT').val(itp_fn_get_before_month() );
			$('#ITP_FORM_RTNMNG03011_SEARCH_TO_DT').val(itp_fn_get_today_ko() );
			$('#ITP_TAB_RTNMNG03011 .input-group.date').datepicker(ITP_DATE_LANGUAGE);
			$('#ITP_FORM_RTNMNG03011_SEARCH_FROM_DT').datepicker();
			$('#ITP_FORM_RTNMNG03011_SEARCH_TO_DT').datepicker();	
			
		},
		grid: function() {
			//listObj.empty.init();
			itp_fn_jqgrid_resize(RTNMNG03011_GRID_ID, RTNMNG03011_GRID_LIST, 'lg');
		},
		ready: function() {
			listObj.init();
		}
	},
	action: function () {
		var _this = this;
		// 검색 납품장소
		$('#ITP_FORM_RTNMNG03011_SSEARCH_SWHS_NM').on('click', function() {
			_this.popup('SW');
		});
		// 검색 납품장소 텍스트 삭제 버튼 클릭
		$('#ITP_FORM_RTNMNG03011_SDELETE_SWHS_NM').on('click', function() {
			$('#ITP_FORM_RTNMNG03011_SEARCH_SWHS_NM').val('');
			$('#ITP_FORM_RTNMNG03011_SEARCH_SWHS_ID').val('');
			
		});
		
		// 검색 공급사 
		$('#ITP_FORM_RTNMNG03011_SSEARCH_SSPPLY_NM').on('click', function() {
			_this.popup('SS');
		});
		// 검색 텍스트 삭제 버튼 클릭
		$('#ITP_FORM_RTNMNG03011_SDELETE_SSPPLY_NM').on('click', function() {
			$('#ITP_FORM_RTNMNG03011_SEARCH_SSPPLY_NM').val('');
			$('#ITP_FORM_RTNMNG03011_SEARCH_SSPPLY_ID').val('');
			
		});
		
		
		// 상세 출하창고
		$('#ITP_BTN_RTNMNG03011_SEARCH_SHMT_WHS_NM').on('click', function() {
			_this.popup('SHW');
		});
		// 검색 납품장소 텍스트 삭제 버튼 클릭
		$('#ITP_BTN_RTNMNG03011_DELETE_SHMT_WHS_NM').on('click', function() {
			$('#ITP_FORM_RTNMNG03011_DETAIL_SHMT_WHS_ID').val('');
			$('#ITP_FORM_RTNMNG03011_DETAIL_SHMT_LOCATION').val('');
			$('#ITP_FORM_RTNMNG03011_DETAIL_SHMT_WHS_NM').val('');
			
		});
		
		
		// 검색 공급사 
		$('#ITP_BTN_RTNMNG03011_NDETAIL_SEARCH_SPPLY_NM').on('click', function() {
			_this.popup('NS');
		});
		// 검색 텍스트 삭제 버튼 클릭
		$('#ITP_BTN_RTNMNG03011_NDETAIL_DELETE_SPPLY_NM').on('click', function() {
			
			var spplyId = $('#ITP_FORM_RTNMNG03011_NDETAIL_SPPLY_ID').val();
			
			
			var records = $(RTNMNG03011_NDETAIL_GRID_ID).getGridParam('reccount')
			
			if (spplyId != '' && records != 0 ) {
				// 공급업체 삭제시 품목까지 삭제 처리되어집니다. 삭제 하시겠습니까?
				var delSpply = {
						callBack: function(args) {
								$('#ITP_FORM_RTNMNG03011_NDETAIL_SPPLY_NM').val('');
								$('#ITP_FORM_RTNMNG03011_NDETAIL_SPPLY_ID').val('');	
								
								// 품목그리드삭제 처리	
								pageObj.grid.clearData('NPC');
								$('#ITP_FORM_RTNMNG03011_NDETAIL .fnPodrAmt').text('');	
							}
					};
					itp_fn_modal_confirm(ITP_MSG_LOCALE.message.ajax.delAllItem, delSpply, null);
			} else {
				$('#ITP_FORM_RTNMNG03011_NDETAIL_SPPLY_NM').val('');
				$('#ITP_FORM_RTNMNG03011_NDETAIL_SPPLY_ID').val('')
			}
		});
		
		// 상세 출하창고
		$('#ITP_BTN_RTNMNG03011_SEARCH_WHS_NM').on('click', function() {
			_this.popup('NHW');
		});
		// 검색 납품장소 텍스트 삭제 버튼 클릭
		$('#ITP_BTN_RTNMNG03011_DELETE_WHS_NM').on('click', function() {
			$('#ITP_FORM_RTNMNG03011_NDETAIL_WHS_ID').val('');
			$('#ITP_FORM_RTNMNG03011_NDETAIL_LOCATION').val('');
			$('#ITP_FORM_RTNMNG03011_NDETAIL_WHS_NM').val('');
			
		});
		
		
	},
	sendPo: function() {
		// 발주전송
		const grid=$(RTNMNG03011_GRID_ID);
		const viewCd='C';
		const gridInsertData = [];
		const brandId=fn_make_user_info.get('brandId');
		const rowKey = grid.getGridParam('selrow');
		if (!rowKey) {
			return itp_fn_modal_alert('선택된 반품발주 요청 내역이 없습니다');
		}
		itp_fn_confirm( '반품발주 요청을 전송 하시겠습니까?', function() { 
			var selectedIds = grid.getGridParam('selarrrow');
			for (var i=selectedIds.length-1; i>=0; i--) {
				const cur=grid.jqGrid('getRowData', selectedIds[i]);
				gridInsertData.push({rtnReqUnqNo: cur.rtnReqUnqNo} );	
			}		  
			ajaxCall('/api/rtnmng/rtn/save-rtnSteamlinePo', {viewCd, brandId, gridInsertData }, function(result) {
				if(result.message) itp_fn_modal_alert(result.message);
				listObj.search();
			}, 'POST'); 
		});
	},
	popup: function (arg) {
		var popFn ;
		// 팝업
		if (arg == "SW") {
			popFn = this.callback.searWhs;
		} else if (arg == "SS") {
			popFn = this.callback.searSpply;
		}  else if (arg == "SHW") {
			popFn = this.callback.searShmtWhs;
		} else if (arg == "NS") {
			popFn = this.callback.searNSpply;
		} else if (arg == "NHW") {
			popFn = this.callback.searNWhs;
		} else if (arg == "REJ") {
			popFn = this.callback.poRej;
		}
		
		const key = {brandId:fn_make_user_info.get('brandId'),storeId:fn_make_user_info.get('storeId')};
		if (arg == "SW" ) {
			const keya = {brandId:fn_make_user_info.get('brandId'),storeId:fn_make_user_info.get('storeId'), whsDvsn:""};
			fn_call_popup('biz', 'BIZPOP_WHS_LOCATION', '#ITP_ASIDE', popFn, keya, 'S');
		} else if (arg == "SS" || arg == "NS" ) {
			fn_call_popup('biz', 'BIZPOP_STORE_SPPLY', '#ITP_ASIDE', popFn, key, 'S');
		} else if (arg == "SHW" || arg == "NHW") {
			const keyb = {brandId:fn_make_user_info.get('brandId'),storeId:"", whsDvsn:"W01"};
			fn_call_popup('biz', 'BIZPOP_WHS_LOCATION', '#ITP_ASIDE', popFn, keyb, 'S');
		} else if (arg == "REJ" ) {
			/* 선택ROW가져오기 */
			const rowKey = $(RTNMNG03011_GRID_ID).getGridParam('selrow');
			if (!rowKey) {
				return;
			}
			
			var selectedIds = $(RTNMNG03011_GRID_ID).getGridParam('selarrrow');
			if(selectedIds.length > 1) { // 1개만 선택
			   alert("구매요청 반려대상에 대해 하나만 선택해주세요 (대표 구매요청번호)") ;
				return;
			} 
			
			var selRowData ;
			
			for (var i=selectedIds.length-1; i>=0; i--) {
				selRowData = $(RTNMNG03011_GRID_ID).jqGrid('getRowData', selectedIds[i]);
			}
			
			const key1 = {pchReqUnqNo:selRowData.pchReqUnqNo, storeId:selRowData.storeId};
			
			fn_call_popup('biz', 'BIZPOP_PO_REJECT', '#ITP_ASIDE', popFn, key1, 'S');
		} 
		
		
	},
	callback: {
		searWhs: function(rowDataPop) {
			if(rowDataPop) {
				$('#ITP_FORM_RTNMNG03011_SEARCH_SWHS_NM').val(rowDataPop.whsNm);
				$('#ITP_FORM_RTNMNG03011_SEARCH_SWHS_ID').val(rowDataPop.whsId);
			}
			
		},
		searSpply: function(rowDataPop) {
			if(rowDataPop) {
				$('#ITP_FORM_RTNMNG03011_SEARCH_SSPPLY_NM').val(rowDataPop.spplyNm);
				$('#ITP_FORM_RTNMNG03011_SEARCH_SSPPLY_ID').val(rowDataPop.spplyId);
			}
			
		},
		searNSpply: function(rowDataPop) {
			if(rowDataPop) {
			   var pspplyId = $('#ITP_FORM_RTNMNG03011_NDETAIL_SPPLY_ID').val();
			   if (pspplyId == "") {
				
					$('#ITP_FORM_RTNMNG03011_NDETAIL_SPPLY_NM').val(rowDataPop.spplyNm);
					$('#ITP_FORM_RTNMNG03011_NDETAIL_SPPLY_ID').val(rowDataPop.spplyId);
				} else {
					var records = $(RTNMNG03011_NDETAIL_GRID_ID).getGridParam('reccount')
					if (records != 0) {
						if (pspplyId != rowDataPop.spplyId ) {
							alert( "추가한 품목의 공급사와 서로 틀립니다 !");
							return ;
						}
					}
					
				}
			}
			
		},
		searShmtWhs: function(rowDataPop) {
			if(rowDataPop) {
				$('#ITP_FORM_RTNMNG03011_DETAIL_SHMT_WHS_NM').val(rowDataPop.whsNm + " - " + rowDataPop.locationNm);
				$('#ITP_FORM_RTNMNG03011_DETAIL_SHMT_WHS_ID').val(rowDataPop.whsId);
				$('#ITP_FORM_RTNMNG03011_DETAIL_SHMT_LOCATION').val(rowDataPop.location);
				
				// 본사배송일경우 해당 창고의 재고를 가져와 출고가능수량에 기입한다.
				// 만약 본사 배송일 경우 진행 처리함		
					
				var param = {};
				let gridUpdateData = [];
				const rowData = $(RTNMNG03011_DETAIL_GRID_ID).getRowData();
				$.each(rowData, function(key, value) {
					gridUpdateData.push(value);
				});

				param.gridSize = 10000;
				param.gridPage = 1;
				param.brandId 	= fn_make_user_info.get('brandId');
				param.whsId 	= rowDataPop.whsId;
				param.location 	= rowDataPop.location;
				param.gridUpdateData = gridUpdateData;
					
				modifyObj.whsPassQty(param);
			
			}
		},
		searNWhs: function(rowDataPop) {
			if(rowDataPop) {
				$('#ITP_FORM_RTNMNG03011_NDETAIL_WHS_NM').val(rowDataPop.whsNm + " - " + rowDataPop.locationNm);
				$('#ITP_FORM_RTNMNG03011_NDETAIL_WHS_ID').val(rowDataPop.whsId);
				$('#ITP_FORM_RTNMNG03011_NDETAIL_LOCATION').val(rowDataPop.location);
			}
		},
		poRej: function(rowDataPop) {
			if(rowDataPop) {
				
				if (rowDataPop.retVal == "Y") {
				  modifyObj.button.rejectSave(rowDataPop);
				}
				
				
			}
		}
		
		
	},
	event: {
		init: function () {
			this.button();
		},
		button: function () {
			// 버튼 클릭 이벤트
			$('button').each(function() {
				var id = $(this).attr('id');
				$(this).on('click', function() {
					switch (id) {
						case 'ITP_BTN_RTNMNG03011_SEB'					: listObj.search();			break;	// 조회 버튼 클릭
						case 'ITP_BTN_RTNMNG03011_RPO'					: pageObj.sendPo(); 		break;	// 발주전송
						case 'ITP_FORM_RTNMNG03011_SSEARCH_COL_PLACE_NM': pageObj.popup('SW'); 		break;	// 수거장소 
					}
				});
			});
			 

		}
	},
	switchScreen: function(mode) {
		$('.itp_det_head').find('button[id^="ITP_BTN_RTNMNG03011_"]').each(function(i) {
			$(this).hide();
		});
		$('#ITP_TAB_RTNMNG03011').find('div[id$="_CONTAINER"]').each(function(i) {
			$(this).hide();
		});
		if(mode == 'LIST') { // 목록
			itp_fn_fire_window_resize();
			$('#ITP_AJAX_RTNMNG03011_LIST_CONTAINER').show();
			fn_show_btn_auth_array(['#ITP_BTN_RTNMNG03011_RPO', '#ITP_BTN_RTNMNG03011_SEB']);
			$('#ITP_FORM_RTNMNG03011_DETAIL_SBRAND_ID').val(fn_make_user_info.get('brandId'));
			$('#ITP_FORM_RTNMNG03011_DETAIL_SSTORE_ID').val(fn_make_user_info.get('storeId'));
			
			$('#ITP_FORM_RTNMNG03011_SDELETE_SSPPLY_NM').show();
			$('#ITP_FORM_RTNMNG03011_SDELETE_SWHS_NM').show();
			$('#ITP_BTN_RTNMNG03011_PO').show();
			SCREEN_MODE = 'LIST' ;
		}  
	},
	grid: {
		 
	}
};

/*목록화면 Object*/
let listObj = {
	init: function () {
		this.grid.init();
	},
	itp_RTNMNG03011_search: false,
	search: function() {
		this.itp_RTNMNG03011_search = true;
		let param = $('#ITP_FORM_RTNMNG03011_SEARCH').serializeObject();
		param.gridSize = $.jgrid.defaults.rowNum;
		param.gridPage = $.jgrid.defaults.page;
		$(RTNMNG03011_GRID_ID).data('grid-param',param);
		$(RTNMNG03011_GRID_ID).setGridParam({'postData': JSON.stringify(param)}).trigger('reloadGrid');
	},
	empty: {
		init: function() { 
		},
		itp_RTNMNG03011_param: {},
		push: function() { 
		},
		back: function() { 
		}
	},
	grid: {
		init: function () {
			// 데이터 없을때
			listObj.empty.push(); 
			this.search();
			
		},
		colModel: gridColModel.list,
		search: function() {
			pageObj.switchScreen('LIST');
			this.unload();
			this.load();
		},
		load: function() {
			let param = $('#ITP_FORM_RTNMNG03011_SEARCH').serializeObject();
			param.gridSize = $.jgrid.defaults.rowNum;
			
			var option = {
				multiselect: true,
				autowidth: true,
				gridId: RTNMNG03011_GRID_ID,
				colModel: gridColModel.list,
				param: param,
				url: DOMAIN + API_DETAIL_GRID_LIST, 
				rownumbers: false,
				beforeProcessing: function(data) { 
					var rows=data.gridRows;
					var cnt=rows.length, prev1='', prev2='', sp1=0, sp2=0;
					var displayAttr=function(sp, ep, field) {
						var rs=ep-sp;
						if( rs>1 ) {
							for(var n=sp; n<ep; n++) {
								var cur=rows[n], attr=cur.attr;
								if(!attr.hasOwnProperty(field) ) {
									attr[field]={};
								}
								if(n==sp) {
									attr[field].rowspan=rs;
								} else {
									attr[field].display='none';
								}
							}
						}
						//attr: {country: {display: "none"}, state: {display: "none"}} 
					};
					for(var n=0;n<=cnt; n++) {
						if(n==cnt) {
							displayAttr(sp1, n, 'rtnReqUnqNo');
							displayAttr(sp2, n, 'rtnWhsNm');
							break;
						} 
						var cur=rows[n];
						if(n==0) {
							cur.attr={ };
						} else {
							cur.attr={ };
						}
						if(prev2!=cur.rtnWhsNm) {							
							displayAttr(sp2, n, 'rtnWhsNm');
							sp2=n;
							prev2=cur.rtnWhsNm;
						}
						if(prev1!=cur.rtnReqUnqNo) {
							displayAttr(sp1, n, 'rtnReqUnqNo');
							displayAttr(sp2, n, 'rtnWhsNm');
							sp1=sp2=n;
							prev2=cur.rtnWhsNm;
							prev1=cur.rtnReqUnqNo;
						}
						
					}
				}, 
				loadComplete: function(data) {
					itp_fn_grid_load_complete(data, RTNMNG03011_GRID_ID, false, 'number', 'RTNMNG03011', listObj.itp_RTNMNG03011_search, listObj.empty, true, data.gridRecords, true);
					var ids = $(RTNMNG03011_GRID_ID).getDataIDs();
					var css = {'background-color':'#FFCCCC'};
					$.each(ids, function(idx, rowId) {
						$(RTNMNG03011_GRID_ID).jqGrid('setCell', rowId, 'storeId', '', ITP_GRID_COL_STYLE.link);
						$(RTNMNG03011_GRID_ID).jqGrid('setCell', rowId, 'dlvReqDt', '', css);
						$(RTNMNG03011_GRID_ID).jqGrid('setCell', rowId, 'whsNm', '', css);
					});
					// $(RTNMNG03011_GRID_ID).setSelection(1, true);
					$('#ITP_RTNMNG03011_jqGrid_list .cbox.checkbox').each(function(idx) {
						var tds=$(this).closest('tr').children('td'), td=tds.eq(2);
						var rs=td.attr('rowspan'), ds=td.css('display'); 
						if(rs) $(this).closest('td').attr('rowspan', rs);
						else if(ds=='none') $(this).closest('td').hide(); 
					});
					const self=this;
					if(self.sortUse) return;
					self.sortUse=true;
					$(POMNG03011_GRID_LIST).find('.ui-jqgrid-labels .ui-th-div').css('cursor','default');
					$(POMNG03011_GRID_LIST).find('.ui-jqgrid-labels .ui-th-div').eq(3).css('cursor','pointer');
					$(POMNG03011_GRID_LIST).find('.ui-jqgrid-labels>th').on('click', function() {
						const idx=$(this).index();
						console.log("xxxx grid header click xxxxxxx index=="+idx, param );
						if(idx==3 || idx==2 ) {
							var field='',sort=self['sort'+idx];
							if(sort ) {
								sort=sort=='asc'?'desc':'asc';
							} else {
								// 등록일 내림차순, 제목 오름차순
								sort=idx==3? 'asc':idx==2? 'desc': 'asc';
							}
							const icon=sort=='asc'? '.glyphicon-triangle-bottom': '.glyphicon-triangle-top'; 
							self['sort'+idx]=sort;
							if(idx==3) {
								field='pchReqUnqNo';
							} else if(idx==2) {
								field='brandNm';
							} 
							param.page=1;
							param.sidx=field;
							param.sord=sort;
							
							$(POMNG03011_GRID_ID).jqGrid('setGridParam',{
								postData:JSON.stringify(param)
							}).trigger('reloadGrid');
							$(this).find('.s-ico').show();
							$(this).find('.ui-grid-ico-sort').hide();
							$(this).find(icon).show();

						}
					});
				}, 
			};
			itp_fn_grid_make_remote(option);
		},
		button: {
		},
		unload : function() {
			$.jgrid.gridUnload(RTNMNG03011_GRID_ID);
		},
		clearData : function() {
			$(RTNMNG03011_GRID_ID).jqGrid('clearGridData', true);
			$(RTNMNG03011_GRID_LIST).find('.ui-jqgrid-bdiv').css('min-height', '100px');
			$(RTNMNG03011_GRID_EMPTY).html(ITP_MSG_LOCALE.message.grid.noData);
			$(RTNMNG03011_GRID_EMPTY).show();
		}
	}, 
};
 
